import React from 'react';
import { Card, Input, Select, DatePicker } from 'antd';
import moment from 'moment';
import Form, { FormItem } from './Form';

const { RangePicker } = DatePicker;

const initialValues = {
  jobDate: [moment().startOf('year'), moment()],
};

const options = [
  {
    value: 'shensong',
    label: '深松',
  },
  {
    value: 'feifang',
    label: '飞防',
  },
];

export default (props) => {
  const { onFinish } = props;

  const handleFinish = (values) => {
    // 转换日期格式
    const { jobDate, ...otherValues } = values;

    onFinish({
      startDate: jobDate[0].format('YYYY-MM-DD'),
      endDate: jobDate[1].format('YYYY-MM-DD'),
      ...otherValues,
    });
  };

  React.useEffect(() => {
    // 开始就触发查询
    handleFinish(initialValues);
  }, []);

  return (
    <Card>
      <Form onFinish={handleFinish} initialValues={initialValues}>
        <FormItem name="orgName" label="合作社">
          <Input placeholder="请输入" />
        </FormItem>
        <FormItem name="userName" label="人员">
          <Input placeholder="请输入" />
        </FormItem>
        <FormItem name="phone" label="手机">
          <Input placeholder="请输入" />
        </FormItem>
        <FormItem name="machineryName" label="农机">
          <Input placeholder="请输入" />
        </FormItem>
        <FormItem name="deviceNo" label="设备编号">
          <Input placeholder="请输入" />
        </FormItem>
        <FormItem name="deviceKind" label="设备类型">
          <Select options={options} />
        </FormItem>
        <FormItem name="jobDate" label="作业时间">
          <RangePicker />
        </FormItem>
      </Form>
    </Card>
  );
};
