import React, { useState, useEffect } from 'react';
import {
  Modal,
  message,
  List,
  Checkbox,
} from 'antd';
import { getRoleList } from '@/services/role';
import { addUserUserRole, deleteUserRole } from '@/services/userRole';
export default (props) => {

  const { rUserId, setRUserId, currentCheckbox, setCurrentCheckbox, editRoleModal, setEditRoleModal } = props
  const [roleList, setRoleList] = useState([]);
  const [rLoading, setRLoading] = useState(false);

  //授权弹窗点击取消按钮
  const onRoleCancel = () => {
    setRUserId();
    setCurrentCheckbox();
    setEditRoleModal(false);
  };
  //授权角色弹窗点击保存按钮
  const handelOk = () => {
    if (!currentCheckbox) {
      message.info('请选择角色');
      return;
    }
    setRLoading(true);
    if (currentCheckbox.length === 0) {
      deleteUserRole(rUserId)
        .then(() => {
          message.success('取消授权角色成功');
          setRLoading(false);
          onRoleCancel();
        })
        .catch((err) => {
          console.log(err.message);
          setRLoading(false);
        });
    } else {
      addUserUserRole(
        rUserId,
        currentCheckbox.map((item) => {
          return { userId: rUserId, roleId: item };
        }),
      )
        .then(() => {
          message.success('授权角色成功');
          setRLoading(false);
          onRoleCancel();
        })
        .catch((err) => {
          console.log(err.message);
          setRLoading(false);
        });
    }
  };
  const handleCheckboxChange = (list) => {
    setCurrentCheckbox(list);
  };
  useEffect(() => {
    //获取角色列表数据
    getRoleList({ pageSize: 999 })
      .then((res) => {
        setRoleList(res.records);
      })
      .catch((err) => {
        console.log(err.message);
      });
  }, []);
  return (
    <Modal
      forceRender
      title="授权角色"
      visible={editRoleModal}
      onCancel={onRoleCancel}
      keyboard={false}
      maskClosable={false}
      destroyOnClose={true}
      onOk={handelOk}
      confirmLoading={rLoading}
    >
      <Checkbox.Group
        style={{ width: '100%' }}
        value={currentCheckbox}
        onChange={handleCheckboxChange}
      >
        <List
          dataSource={roleList}
          renderItem={(item) => (
            <List.Item>
              <Checkbox value={item.roleId}>{item.name}</Checkbox>
            </List.Item>
          )}
        />
      </Checkbox.Group>
    </Modal>

  )
}