import {
  Button,
  Modal,
  Form,
  Input,
  message,
  Radio,
  Select,
} from 'antd';
import { useEffect, useState } from 'react';
import Search from '@/components/CooperativeSearch';
import {
  addUser,
  updateUser,
  getDefaultPassword
} from '@/services/user';

const FormItem = Form.Item;
const { Option } = Select;
const formItemLayout = { labelCol: { span: 6 }, wrapperCol: { span: 14 } };
export default (props) => {
  const { editModal, onCancel, actionRef, form, orgId, userId } = props
  const [loading, setLoading] = useState(false);
  const [password, setPassWord] = useState('');

  // 编辑弹窗的表单提交
  const Submit = (values) => {
    const newData = { ...values };
    if (!newData.sex && newData.sex !== 0) {
      newData.sex = 1;
    }
    setLoading(true);
    if (!/^1[0-9]{10}$/.test(newData.phone)) {
      message.warning('请输入正确的十一位手机号');
      setLoading(false);
      return false;
    }
    if (
      !/^[1-9]\d{5}(18|19|([23]\d))\d{2}((0[1-9])|(10|11|12))(([0-2][1-9])|10|20|30|31)\d{3}[0-9Xx]$/.test(
        newData.idCard,
      )
    ) {
      message.warning('请输入正确的身份证号');
      setLoading(false);
      return false;
    }

    if (userId) {
      updateUser(userId, newData)
        .then(() => {
          setLoading(false);
          message.success(`修改成功`);
          onCancel();
          actionRef.current.reload();
        })
        .catch((err) => {
          setLoading(false);
          console.log(err.message);
        });
    } else {
      addUser(newData)
        .then(() => {
          setLoading(false);
          message.success(`保存成功`);
          onCancel();
          actionRef.current.reload();
        })
        .catch((err) => {
          setLoading(false);
          message.error(err.message || err);
        });
    }
  };
  // 弹窗表单中合作社搜索框改变事件目前没用
  const handelChange = () => { };
  useEffect(() => {
    //获取账号默认密码
    getDefaultPassword()
      .then((res) => {
        setPassWord(res);
      })
      .catch((err) => {
        console.log(err.message);
      });
  }, [])
  return (
    <Modal
      forceRender
      title={userId ? '人员编辑' : '人员新增'}
      visible={editModal}
      onCancel={onCancel}
      keyboard={false}
      maskClosable={false}
      destroyOnClose={true}
      footer={null}
    >
      <Form {...formItemLayout} onFinish={Submit} form={form}>
        <FormItem label="用户名" name="userName" rules={[{ required: true, message: '请输入' }]}>
          <Input placeholder="请输入" />
        </FormItem>
        <FormItem label="性别" name="sex" rules={[{ required: true, message: '请选择' }]}>
          <Radio.Group>
            <Radio value={1}>男</Radio>
            <Radio value={0}>女</Radio>
          </Radio.Group>
        </FormItem>
        <FormItem label="手机号" name="phone" rules={[{ required: true, message: '请输入' }]}>
          <Input maxLength="11" placeholder="请输入" />
        </FormItem>
        <FormItem label="身份证" name="idCard" rules={[{ required: true, message: '请输入' }]}>
          <Input placeholder="请输入" />
        </FormItem>
        <FormItem
          label="登录账号"
          name="loginName"
          rules={[{ required: true, message: '请输入登录账号' }]}
        >
          <Input placeholder="请输入" />
        </FormItem>
        <FormItem label=" " colon={false} style={{ height: '4px', marginTop: '-28px' }}>
          <span style={{ opacity: '0.7' }}>默认密码{password}</span>
        </FormItem>
        <FormItem label="所属合作社" name="orgId" rules={[{ required: true, message: '请输入' }]}>
          <Search placeholder="请输入合作社" disabled={orgId && !userId ? true : false} onChange={handelChange} />
        </FormItem>
        {userId && (
          <FormItem
            label="合作社管理员"
            name="isOrgManager"
            rules={[{ required: true, message: '请选择' }]}
          >
            <Select placeholder="请选择是否启用">
              <Option value={false}>否</Option>
              <Option value={true}>是</Option>
            </Select>
          </FormItem>
        )}
        <FormItem label="状态" name="status" rules={[{ required: true, message: '请选择' }]}>
          <Select placeholder="请选择是否启用">
            <Option value={1}>启用</Option>
            <Option value={0}>禁用</Option>
          </Select>
        </FormItem>
        <FormItem label=" " colon={false}>
          <Button type="default" onClick={onCancel}>
            取消
          </Button>
          <Button
            type="primary"
            loading={loading}
            htmlType="Submit"
            style={{ marginLeft: '4em' }}
          >
            确认
          </Button>
        </FormItem>
      </Form>
    </Modal>

  )
}